@@ -147,7 +147,7 @@ void BackendInterface::setBackendHasError(const QString& errorDetails)
     Q_UNUSED(errorDetails)
 }
 
-void BackendInterface::setBackendIsReady(BrightnessControlsList availableBrightnessControls,
+void BackendInterface::setBackendIsReady(const BrightnessControlsList &availableBrightnessControls,
                                          BackendInterface::SuspendMethods supportedSuspendMethods)
 {
     d->brightnessControlsAvailable = availableBrightnessControls;
@@ -207,9 +207,9 @@ void BackendInterface::setCapabilities(BackendInterface::Capabilities capabiliti
     d->capabilities = capabilities;
 }
 
-int BackendInterface::calculateNextStep(int value, int valueMax, BrightnessControlType type, BrightnessLogic::BrightnessKeyType keyType)
+int BackendInterface::calculateNextStep(int value, int valueMax, BrightnessControlType controlType, BrightnessLogic::BrightnessKeyType keyType)
 {
-    BrightnessLogic *logic = d->brightnessLogic.value(type);
+    BrightnessLogic *logic = d->brightnessLogic.value(controlType);
     logic->setValueMax(valueMax);
     logic->setValue(value);
 
